@@ -23,14 +23,18 @@ class Model(object):
             url = rp.json()["url"]
             return url
 
-    def download_model(self, save_path):
+    def get_model_content(self) -> bytes:
+        url = self.get_model_url()
+        content = requests.get(url).content
+        return content
+
+    def save_model(self, save_path):
         if os.path.exists(save_path):
             sys.stdout.write(f"[{save_path}] exists!")
         else:
             sys.stdout.write(f"model [{self.version}] downloading...")
-            url = self.get_model_url()
             with open(save_path, "wb") as f:
-                content = requests.get(url).content
+                content = self.get_model_content()
                 f.write(content)
 
     @property
